@@ -31,7 +31,8 @@ STIM_PARAM_TAGS = (('membrane_stimulus_current_amplitude', 'uA_per_cm2', True),
                    ('membrane_stimulus_current_end', 'millisecond', False))
 
 
-def load_model_with_conversions(model_file, use_modifiers=False, quiet=False, skip_singularity_fixes=False):
+def load_model_with_conversions(model_file, use_modifiers=False, quiet=False, skip_singularity_fixes=False,
+                                skip_conversions=False):
     if quiet:
         LOGGER.setLevel(logging.ERROR)
     try:
@@ -45,11 +46,12 @@ def load_model_with_conversions(model_file, use_modifiers=False, quiet=False, sk
         excluded = (tagged | annotated) - set(model.get_derived_quantities(sort=False))
 
         model.remove_fixable_singularities(V, exclude=excluded)
-    add_conversions(model, use_modifiers=use_modifiers)
+    if not skip_conversions:
+        add_conversions(model, use_modifiers=use_modifiers)
     return model
 
 
-def add_conversions(model, use_modifiers=True):
+def add_conversions(model, use_modifiers=True, skip_chaste_stimulus_conversion=False):
     # We are adding attributes to the model from cellmlmanip. This could break if the api changes
     # The check  below guards against this
     attrs_added = ('conversion_units', 'stimulus_units', 'time_variable', 'state_vars', 'membrane_voltage_var',
@@ -80,7 +82,8 @@ def add_conversions(model, use_modifiers=True):
     model.stimulus_sign = _get_stimulus_sign(model)
 
     # Add conversion rules for working with stimulus current & amplitude
-    _add_conversion_rules(model)
+    if not skip_chaste_stimulus_conversion:
+        _add_conversion_rules(model)
 
     model.time_variable = _get_time_variable(model)
     model.state_vars = set(model.get_state_variables(sort=False))
@@ -95,7 +98,7 @@ def add_conversions(model, use_modifiers=True):
 
     # Get Capactiatnce & stimulus parameters
     model.membrane_capacitance = _get_membrane_capacitance(model)
-    model.stimulus_params, model.stimulus_equations = _get_stimulus(model)
+    model.stimulus_params, model.stimulus_equations = _get_stimulus(model, skip_chaste_stimulus_conversion)
 
     # update modifiable_parameters remove stimulus params
     # couldn't do this earlier as we didn't have stimulus params yet
@@ -110,11 +113,13 @@ def add_conversions(model, use_modifiers=True):
 
     model.y_derivatives = _get_y_derivatives(model)
     # Convert currents
-    model.membrane_stimulus_current_converted, model.stimulus_units = _convert_membrane_stimulus_current(model)
+    model.membrane_stimulus_current_converted, model.stimulus_units = \
+        _convert_membrane_stimulus_current(model, skip_chaste_stimulus_conversion)
     _convert_other_currents(model)
 
     # Get derivs and eqs
-    model.i_ionic_lhs, model.ionic_vars = _get_ionic_vars(model)
+    model.i_ionic_lhs, model.ionic_vars = \
+        _get_ionic_vars(model, skip_chaste_stimulus_conversion=skip_chaste_stimulus_conversion)
     model.extended_ionic_vars = _get_extended_ionic_vars(model)
     model.derivative_equations = get_equations_for(model, model.y_derivatives)
 
@@ -325,25 +330,26 @@ def _get_membrane_capacitance(model):
     return capacitance
 
 
-def _get_stimulus(model):
+def _get_stimulus(model, skip_chaste_stimulus_conversion):
     """ Store the stimulus currents in the model"""
-    stim_params_orig, stim_params = set(), set()
-    try:  # Get required stimulus parameters
-        for tag, unit, required in STIM_PARAM_TAGS:
-            param = model.get_variable_by_ontology_term((OXMETA, tag))
-            stim_params_orig.add(param)  # originals ones
-            stim_params.add(model.convert_variable(param, model.conversion_units.get_unit(unit),
-                                                   DataDirectionFlow.INPUT))
-    except KeyError:
-        if required:  # Optional params are allowed to be missing
-            LOGGER.info('The model has no default stimulus params tagged.')
-            return set(), []
-    except TypeError as e:
-        if str(e) == "unsupported operand type(s) for /: 'HeartConfig::Instance()->GetCapacitance' and 'NoneType'":
-            e = CodegenError("Membrane capacitance is required to be able to apply conversion to stimulus current!")
-        raise(e)
+    stim_params_orig, stim_params, return_stim_eqs = set(), set(), set()
+    if not skip_chaste_stimulus_conversion:
+        try:  # Get required stimulus parameters
+            for tag, unit, required in STIM_PARAM_TAGS:
+                param = model.get_variable_by_ontology_term((OXMETA, tag))
+                stim_params_orig.add(param)  # originals ones
+                stim_params.add(model.convert_variable(param, model.conversion_units.get_unit(unit),
+                                                       DataDirectionFlow.INPUT))
+        except KeyError:
+            if required:  # Optional params are allowed to be missing
+                LOGGER.info('The model has no default stimulus params tagged.')
+                return set(), []
+        except TypeError as e:
+            if str(e) == "unsupported operand type(s) for /: 'HeartConfig::Instance()->GetCapacitance' and 'NoneType'":
+                e = CodegenError("Membrane capacitance is required to be able to apply conversion to stimulus current!")
+            raise(e)
 
-    return_stim_eqs = get_equations_for(model, stim_params, filter_modifiable_parameters_lhs=False)
+        return_stim_eqs = get_equations_for(model, stim_params, filter_modifiable_parameters_lhs=False)
     return stim_params | stim_params_orig, return_stim_eqs
 
 
@@ -404,9 +410,9 @@ def _stimulus_sign(model, expr_to_check, equations, stimulus_current=None):
     return - 1 if expr_to_check > 0 else 1
 
 
-def _convert_membrane_stimulus_current(model):
+def _convert_membrane_stimulus_current(model, skip_chaste_stimulus_conversion):
     """ Find the membrane_stimulus_current and convert it to uA_per_cm2, using GetIntracellularAreaStimulus"""
-    if model.membrane_stimulus_current_orig is None:
+    if model.membrane_stimulus_current_orig is None or skip_chaste_stimulus_conversion:
         return None, model.stimulus_units
 
     membrane_stimulus_current_converted = model.convert_variable(model.membrane_stimulus_current_orig,
@@ -503,7 +509,7 @@ def _get_stimulus_sign(model):
     return _stimulus_sign(model, model.dvdt_eq[0].rhs, d_eqs, stimulus_current=model.membrane_stimulus_current_orig)
 
 
-def _get_ionic_vars(model):
+def _get_ionic_vars(model, skip_chaste_stimulus_conversion=False):
     """ Get the equations defining the ionic derivatives"""
     # retrieve ionic currents by metadata and add equation
 
@@ -513,8 +519,12 @@ def _get_ionic_vars(model):
     ionic_vars = model.get_variables_by_rdf((PYCMLMETA, 'ionic-current_chaste_codegen'), 'yes')
     # convert and sum up all lhs for all ionic equations
     for var in reversed(ionic_vars):
-        factor = model.units.get_conversion_factor(from_unit=model.units.evaluate_units(var),
-                                                   to_unit=model.conversion_units.get_unit('uA_per_cm2'))
+        try:
+            factor = model.units.get_conversion_factor(from_unit=model.units.evaluate_units(var),
+                                                       to_unit=model.conversion_units.get_unit('uA_per_cm2'))
+        except DimensionalityError:
+            factor = 1
+
         i_ionic_rhs += factor * var
     i_ionic_rhs = simplify(i_ionic_rhs * model.ionic_stimulus_sign)  # clean up equation
 
